function[Nl,att]=liebe_gas(f,TC,rh,p_hPa,M,M2);
% Calculates complex refractivity Nl and attenuation for atmospheric gases
% using Liebe et al 1989 Int. J. Infrared & Millimetre waves, 10(6) 631
% inputs:
% f=frequency [GHz]
% TC=temperature [C]
% RH=relative humidity [%]
% p_hPa=pressure in hPa or mb
% outputs:
% Nl = complex refractivity
% att = dB/km attenuation (one way)
% ALSO NEEDED: two data files containing line parameters for O2 and H2O
% (L_oxygen_data.mat L_vapour_data.mat)
% This is my attempt to implement the equations and data in the paper.
% It seems to work, but I make no guarantees that it is perfect. Do check
% for yourself! 
% Chris Westbrook 20 June 2019
% adjusted 21 June 2019: data tables for line parameters now passed to
% function by calling script, rather than loaded every time

% compute temp,pressure etc parameters needed
TK=273.15+TC;
esat=100*1.333*exp(20.386-5132/TK); % in Pa
e_Pa=esat*(rh/100);
e=1e-3*e_Pa; % kPa
p=p_hPa/10; % kPa
theta=300/(TK);

% non-dispersive refractivity (no frequency dependence = do only once)
% doesn't affect imaginary part or attenuation
N1=2.588*p*theta;
N2=41.63*theta+2.39*e*theta;
N0=N1+N2;
nondispersive=N0+N1+N2;

% dispersive refractivity...
% Nl_oxygen, Nl_vapour = effect of specific lines
% first, the oxygen lines:
%load L_oxygen_data
f0=M(:,1); a1=M(:,2);a2=M(:,3);a3=M(:,4);a4=M(:,5);a5=M(:,6);a6=M(:,7);
S=a1.*1e-6*p*theta^3.*exp(a2*(1-theta));
gamma=a3.*1e-3.*(p*theta.^(0.8-a4)+1.1*e*theta*ones(length(a4),1)); % for O2
A=gamma.*f./f0; B=(f0.^2+gamma.^2)./f0; X=(f0-f).^2+gamma.^2; Y=(f0+f).^2+gamma.^2;
delta=(a5+a6*theta)*1e-3*p*theta^0.8;
F_im=A./X+A./Y-delta.*(f./f0).*((f0-f)./X+(f0-f)./Y);
F_re=(B-f)./X+(B+f)./Y-2./f0+delta.*(A./X-A./Y);
F_complex=F_re+i*F_im;
Nl_oxygen=sum(S.*F_complex);
% next water vapour:
%load L_vapour_data
f0=M2(:,1); b1=M2(:,2);b2=M2(:,3);b3=M2(:,4);b4=M2(:,5);b5=M2(:,6);b6=M2(:,7);
S=b1.*e.*theta^3.5.*exp(b2*(1-theta));
gamma=b3.*1e-3.*(p*theta.^b4+b5.*e.*theta.^b6); 
delta=0;
A=gamma.*f./f0; B=(f0.^2+gamma.^2)./f0; X=(f0-f).^2+gamma.^2; Y=(f0+f).^2+gamma.^2;
F_im=A./X+A./Y-delta.*(f./f0).*((f0-f)./X+(f0-f)./Y);
F_re=(B-f)./X+(B+f)./Y-2./f0+delta.*(A./X-A./Y);
F_complex=F_re+i*F_im;
Nl_vapour=sum(S.*F_complex);

% dry continuum (Oxygen & Nitrogen) - small
% Liebe 92 formulation:
Sd=6.14e-4*p*theta^2; % strength
gamma0=5.6e-3*(p+1.1*e)*theta; % width
ap=1.40*(1-1.2e-5*f^1.5)*1e-10;
Nd_im=Sd*f/(gamma0*(1+(f/gamma0)^2))+ap*f*p^2*theta^3.5; % The equation in Liebe 89 is a bit ambiguous if the (1+(f/gamma0)^2) is on bottom or top. Assume bottom (based on Liebe 85, and numbers produced)
Nd_re=Sd*(1/(1+(f/gamma0)^2)-1);
Nd=Nd_re+i*Nd_im;
% Commented out here is Liebe 85 for comparison (sanity check)
% a0=3.07e-4; gamma0=5.6e-3*(p+1.1*e)*theta^0.8; ap=1.4*(1-1.2*f^1.5*1e-5)*1e-10;
% Nd_im=(2*a0*(gamma0*(1+(f/gamma0)^2)*(1+(f/60)^2))^(-1)+ap*p*theta^2.5)*f*p*theta^2;
% Nd_re=a0*((1+(f/gamma0)^2)^(-1)-1)*p*theta^2;
% Nd=Nd_re+i*Nd_im;
% Nd_85=Nd;

% water vapour continuum
bs=3.57*theta^7.5; bf=0.113; bo=0.998;
Nc_im=f*(bs*e+bf*p)*1e-5*e*theta^3;
Nc_re=f^2*bo*(1-0.20*theta)*1e-5*e*theta^2.7;
Nc=Nc_re+i*Nc_im;

Nl=Nl_oxygen+Nl_vapour+Nd+Nc+nondispersive;

att=0.182*f*imag(Nl);



